#-*- coding: utf-8 -*-
u"""Defines the `BlocksPage` model.

.. moduleauthor:: Martí Congost <marti.congost@whads.com>
"""
from woost.models.page import (
    Page as BlocksPage,
    PageTranslation as BlocksPageTranslation
)

