#-*- coding: utf-8 -*-
"""

@author:		Marc Pérez
@contact:		marc.perez@whads.com
@organization:	Whads/Accent SL
@since:			December 2009
"""
from cocktail.translations import translations

translations.define("googlesearch next",
    es = u"Siguiente",
    en = u"Next",
    fr = u"Suivante",
    ca = u"Següent"
)

translations.define("googlesearch previous",
    es = u"Anterior",
    en = u"Previous",
    fr = u"Dernière",
    ca = u"Anterior"
)

# Configuration
#------------------------------------------------------------------------------
translations.define("Configuration.services.google_cse",
    ca = u"Google CSE",
    es = u"Google CSE",
    en = u"Google CSE"
)

translations.define("Configuration.google_search_engine_id",
    ca = u"Identificador del cercador",
    es = u"Indentificador del buscador",
    en = u"Search engine id"
)

translations.define("Configuration.google_search_results_page",
    ca = u"Pàgina de resultats de cerca",
    es = u"Página de resultados de búsqueda",
    en = u"Search results page"
)

# Website
#------------------------------------------------------------------------------
translations.define("Website.services.google_cse",
    ca = u"Google CSE",
    es = u"Google CSE",
    en = u"Google CSE"
)

translations.define("Website.google_search_engine_id",
    ca = u"Identificador del cercador",
    es = u"Indentificador del buscador",
    en = u"Search results page"
)

translations.define("Website.google_search_results_page",
    ca = u"Pàgina de resultats de cerca",
    es = u"Página de resultados de búsqueda",
    en = u"Search results page"
)

