
html, body {
    margin: 0;
    padding: 0;
}

* {
    box-sizing: content-box;
    -moz-box-sizing: content-box;
    -webkit-box-sizing: content-box;
}

body {
    font-family: Bitstream Vera Sans, Arial;
    font-size: 11pt;
}

.BackOfficeLayout button {
	font-family: Bitstream Vera Sans, Arial;
}

.BackOfficeLayout button.button,
.BackOfficeLayout input[type=submit],
.BackOfficeLayout .AsyncFileUploader .button {
    background-color: #ddd;
    background-image: -moz-linear-gradient(#f6f6f6,#ccc);
    background-image: -webkit-linear-gradient(#f6f6f6,#ccc);
    padding: 0.3em 0.7em;
    border-radius: 0.3em;
    border: 1px solid #aaa;
    -moz-box-shadow: 1px 1px 4px #bbb;
    cursor: pointer;
    font-size: 0.9em;
    color: #222;
}

.BackOfficeLayout button.button:hover,
.BackOfficeLayout input[type=submit]:hover,
.BackOfficeLayout .AsyncFileUploader .button:hover {
    background-color: #eee;
    background-image: -moz-linear-gradient(white,#ddd);
    background-image: -webkit-linear-gradient(white,#ddd);
}

.BackOfficeLayout .header {
    position: relative;
    padding: 0.6em 1em;
    height: 1.5em;
    background-repeat:repeat-y;
    background-color: #3e4351;
}

.BackOfficeLayout .header h1 {
    float: left;
    font-size: 120%;
    padding: 0;
    margin: 0;
    color: white;
    text-shadow: 0 0 6px rgba(30,30,30,0.8);
}

.BackOfficeLayout .header h1 a {
    text-decoration: none;
    color: inherit;
}

.BackOfficeLayout .identity {
    position: absolute;
    bottom: 1em;
    right: 1em;
    border-radius: 0.2em;
    color: white;
}

.BackOfficeLayout .identity strong {
    font-size: 0.8em;
    font-weight: bold;
}

.BackOfficeLayout .identity form {
    display: inline;
    margin: 0;
    padding: 0;
}

.BackOfficeLayout .identity form button.logout_button {
    font-size: 0.8em;
    margin-left: 0.7em !important;
    color: rgba(255,255,255,0.8) !important;
    text-decoration: underline !important;
}

.BackOfficeLayout .identity button:hover {
    color: white !important;
}

.BackOfficeLayout .user_views_bar {
    padding: 0.3em 0.8em;
    background-color: rgb(245,245,245);
    border-bottom: 1px solid #ccc;
}

.BackOfficeLayout .user_views_bar {
    margin: 0;
    padding: 0.3em 1em;
}

.BackOfficeLayout .user_views_bar span,
.BackOfficeLayout .user_views_bar a {
    font-size: 0.8em;
}

.BackOfficeLayout .user_views_label {
    margin-right: 0.5em;
}

.BackOfficeLayout .user_views_list {
    display: inline;
    list-style-type: none;
    padding: 0;
    margin: 0;
}

.BackOfficeLayout .user_views_list li {
    padding: 0;
    margin: 0;
    margin-right: 1em;
    display: inline;
}

.BackOfficeLayout .user_views_bar a {
    color: rgb(75,85,95);
}

.BackOfficeLayout a,
.BackOfficeLayout .identity button,
.BackOfficeLayout .user_views_bar .add_user_view_button,
.BackOfficeLayout .advanced_search,
.BackOfficeEditView .discard_button,
.BackOfficeFieldsView .ItemSelector-button {
    font-size: inherit;
    background: none;
    border: none;
    color: rgb(50,80,110);
    margin: 0;
    padding: 0;
    cursor: pointer;
}

.BackOfficeLayout .user_views_bar .add_user_view_button {
    color: rgb(75,75,75);
    text-decoration: none;
}

.BackOfficeLayout .user_views_bar .add_user_view_button img {
    vertical-align: middle;
}

.BackOfficeLayout a img {
    border: none;
}

.BackOfficeLayout .CheckList div {
    white-space: nowrap;
}

.BackOfficeLayout .Selector .column {
    display: inline-block;
    vertical-align: top;
}

.BackOfficeLayout .Selector .column + .column {
    margin-left: 1.5em;
}

.TreeSelector li {
    list-style-type: none;
}

.BackOfficeLayout .no_match {
    display: none;
}

/* Tabs */
.scripted .BackOfficeEditView .ContentForm > .fields > fieldset {
    display: none;
    margin: 0;
}

.scripted .BackOfficeEditView .ContentForm > .fields > fieldset > .fieldset_fields {
    border: none;
    margin: 0;
    padding: 0;
    padding-left: 0.6em;
}

.scripted .BackOfficeEditView .ContentForm > .fields > fieldset > legend {
    display: none;
}

.scripted .BackOfficeEditView .ContentForm > .fields > fieldset.selected {
    display: block;
}

.BackOfficeEditView .tabStrip {
    margin-bottom: 2em;
    border-bottom: 1px solid #ccc;
}

.BackOfficeLayout .tabs {
    clear: both;
    overflow: visible;
    border-bottom: 1px solid rgb(200,210,220);
    border-left: none;
    border-right: none;
    margin-top: 0.75em;
    margin-bottom: 0.5em;
    height: 1.7em;
}

.BackOfficeLayout .tab {
    color: #666;
    position: relative;
    top: 1px;
    height: 1.15em;
    display: inline-block;
    background-color: #f0f0f0;
    padding-left: 0.4em;
    padding-top: 0.4em;
    padding-bottom: 0.5em;
    padding-right: 0.4em;
    margin-left: 0.2em;
    border: 1px solid #d8d8d8;
    border-bottom-color: #ccc;
    -moz-border-radius-topleft: 5px;
    -moz-border-radius-topright: 5px;
    -webkit-border-top-left-radius: 5px;
    -webkit-border-top-right-radius: 5px;
    border-top-left-radius: 5px;
    border-top-right-radius: 5px;
    font-size: 90%;
    cursor: pointer;
}

.BackOfficeLayout .tab.selected {
    color: #333;
    border-color: #ccc;
    border-bottom-color: white;
    background-color: white;
}

.BackOfficeLayout h2 {
    font-size: inherit;
}

.BackOfficeLayout .body {
    clear: both;
    padding: 1em;
}

.BackOfficeLayout .selection_options {
    font-size: 85%;
    margin: 1em;
    margin-bottom: 0.6em;
}

.BackOfficeLayout .ItemLabel {
    display: inline-block;
    background-repeat: no-repeat;
}

.BackOfficeLayout .ItemLabel.with_icon {
    white-space: nowrap;
}

.BackOfficeLayout .ItemLabel.with_icon .text_wrapper {
    white-space: normal;
}

.BackOfficeLayout .ItemLabel.with_icon > * {
    display: inline-block;
    vertical-align: middle;
}

.BackOfficeLayout input[type=text],
.BackOfficeLayout input[type=password],
.BackOfficeLayout input[type=url],
.BackOfficeLayout input[type=email],
.BackOfficeLayout input[type=number],
.BackOfficeLayout input[type=search],
.BackOfficeLayout input[type=tel],
.BackOfficeLayout textarea,
.BackOfficeLayout .CodeMirror-wrapping {
    border: 1px solid rgb(200,200,200);
    padding: 0.2em;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}

.BackOfficeLayout input[type=search] {
    padding-left: 1.6em !important;
    background: white url(/resources/images/search_box.png) 0.3em center no-repeat;
}

.BackOfficeLayout .CodeMirror-wrapping {
    clear: left;
    width: 45em !important;
    height: 10em !important;
}

.BackOfficeLayout .TreeView .filtered {
    opacity: 0.5;
}

.BackOfficeLayout .shortcut {
    text-decoration: underline;
    vertical-align: baseline !important;
}

.BackOfficeLayout a[disabled] {
    opacity: 0.5;
    text-decoration: none;
    cursor: default;
}

.BackOfficeLayout .selector a {
    text-decoration: none;
}

.BackOfficeLayout .CheckList input,
.BackOfficeLayout .MemberList input {
    vertical-align: bottom;
}

.BackOfficeLayout .RadioSelector input + label,
.BackOfficeLayout .CheckList input + label,
.BackOfficeLayout .MemberList input + label {
    display: inline;
    margin-left: 0.2em;
}

.BackOfficeLayout .CheckList .group_label,
.BackOfficeLayout .RadioSelector .group_label {
    font-weight: bold;
}

.BackOfficeLayout .CheckList .group,
.BackOfficeLayout .RadioSelector .group {
    margin-bottom: 0.8em;
}

.BackOfficeLayout .MemberList .content_type > .label {
    text-decoration: underline;
}

.BackOfficeLayout .MemberList .content_type {
    margin-top: 1em;
    margin-left: 2em;
}

/* Collection editor
-----------------------------------------------------------------------------*/
.CollectionEditor > .entries > .entry {
    white-space: nowrap;
}

/* Item collection editor
-----------------------------------------------------------------------------*/
.ItemCollectionEditor .ActionBar.toolbar {
    margin-bottom: 0;
}

.ItemCollectionEditor ul.entries {
    display: block;
    list-style-type: none;
    padding: 0;
    margin: 0;
    background-color: white;
}

.ItemCollectionEditor ul.entries li {
    cursor: pointer;
    display: block;
    padding: 0;
    margin: 0;
    border: 1px solid #ddd;
    border-top: none;
    padding: 0.4em;
}

.ItemCollectionEditor ul.entries li.selected {
    background-color: #4b4b4b;
    border-color: #4b4b4b;
    color: white;
}

.scripted .ItemCollectionEditor ul.entries li input[type=checkbox] {
    display: none;
}

.ItemCollectionEditor ul.entries li label {
    margin: 0;
    padding: 0 !important;
    font-size: 0.9em;
}

.ItemCollectionEditor ul.entries li.ui-sortable-helper {
    width: 100%;
    border-top: 1px solid #ddd;
    background-color: white;
    opacity: 0.7;
    box-sizing: border-box;
}

/* Item selector
-----------------------------------------------------------------------------*/
.BackOfficeItemSelectorView .content_type_selector > .entry_label {
    font-size: 85% !important;
    color: rgb(50,50,50) !important;
}

body.modal {
    overflow: hidden;
}

.ItemSelector-background,
.dialog-background {
    z-index: 10000;
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-color: #999;
    opacity: 0.7;
}

.ItemSelector-frame,
.dialog {
    z-index: 10001;
    border: none;
    position: fixed;
    top: 4%;
    left: 4%;
    width: 92%;
    height: 92%;
    background-color: white;
    box-shadow: 3px 3px 7px #666;
}

.dialog {
    overflow: auto;
}

.ImageGallery-dialog {
    left: auto;
    top: auto;
    right: auto;
    bottom: auto;
    width: auto;
    height: auto;
}

/* Forms
-----------------------------------------------------------------------------*/
.BackOfficeLayout fieldset {
    border: none;
    margin: 0;
    padding: 0;
    margin-top: 0.75em;
    margin-bottom: 0.75em;
}

.BackOfficeLayout .Form fieldset div.field:last-child {
    margin-bottom: 0;
}

.BackOfficeLayout fieldset + fieldset {
    margin-top: 2em;
}

.BackOfficeLayout fieldset legend,
.scripted .BackOfficeEditView .ContentForm > .fields > fieldset .fieldset_fields > fieldset > legend {
    position: relative;
    font-weight: bold;
    margin: 0;
    padding: 0;
    padding-bottom: 0.2em;
    color: #545f75;
}

.BackOfficeLayout fieldset fieldset legend {
    font-size: 0.9em;
    color: rgb(70,70,70);
}

.BackOfficeLayout fieldset .fieldset_fields,
.scripted .BackOfficeEditView .ContentForm > .fields > fieldset .fieldset_fields > fieldset > .fieldset_fields {
    border-top: 1px solid #adb2bc;
    margin-top: 0;
    padding-top: 1em;
    padding-left: 0.75em;
}

.scripted .BackOfficeEditView .ContentForm > .fields > fieldset .fieldset_fields > fieldset > .fieldset_fields {
    border: none;
    border-top: 1px solid #adb2bc;
    background-color: inherit;
}

.BackOfficeLayout fieldset.anonymous > .fieldset_fields {
    border-top: none;
    padding-top: 0;
}

.BackOfficeLayout fieldset fieldset .fieldset_fields {
    border: 1px solid #ccc;
    background-color: #eee;
    padding: 0.5em;
}

.BackOfficeLayout .field input.control,
.BackOfficeLayout .field textarea.control,
.BackOfficeLayout .field select.control {
    width: 18em;
}

.BackOfficeLayout .field input.ColorPicker {
    width: 5em;
}

.BackOfficeLayout .field button.control {
    width: 12em;
}

.BackOfficeLayout .field .mceEditor .mceLayout {
    width: 16.85em !important;
}

.BackOfficeLayout .buttons {
    clear: both;
    padding: 1em;
    text-align: right;
}

.BackOfficeLayout .buttons button {
    width: 11em;
}

.BackOfficeLayout .buttons button + button {
    margin-left: 0.8em;
}

.BackOfficeLayout .Form .fields > table > tbody > tr > td,
.BackOfficeLayout .Form fieldset > table > tbody > tr > td {
    padding-right: 1.5em;
    padding-bottom: 0.5em;
}

.BackOfficeLayout .Form div.field {
    clear: left;
    margin-bottom: 1.5em;
}

.BackOfficeLayout .Form div.field.translated {
    clear: left;
    margin-bottom: 1em;
}

.BackOfficeLayout .Form div.field:after {
    content: ".";
    display: block;
    height: 0;
    clear: both;
    visibility: hidden;
}

.BackOfficeLayout .Form tr.field {
    clear: none;
}

.BackOfficeLayout .Form div.field_instance {
    float: left;
    margin-right: 1.5em;
    padding: 0.2em;
}

.BackOfficeLayout .Form .translated div.field_instance {
    margin-bottom: 0.5em;
}

.BackOfficeLayout .Form td.field_instance {
    padding: 0.4em;
}

.BackOfficeLayout .Form .explanation {
    clear: both;
    padding-top: 0.5em;
    padding-left: 0;
    margin-left: 1em;
    color: rgb(75,75,75);
    font-size: 0.8em;
    max-width: 38em;
    text-align: justify;
}

.BackOfficeLayout .Form .explanation dl {
    margin-left: 1em;
}

.BackOfficeLayout .Form .explanation dt {
    font-weight: bold;
    color: #333;
    margin-bottom: 0.2em;
}

.BackOfficeLayout .Form .explanation dd {
    margin-left: 0;
}

.BackOfficeLayout .Form .explanation dd + dt {
    margin-top: 0.8em;
}

.BackOfficeLayout .Form label {
    display: block;
    padding-bottom: 0.2em;
}

.BackOfficeLayout .Form .field_language {
    color: rgb(75,75,75);
    font-style: italic;
    font-size: 75%;
}

.BackOfficeLayout .Form.redundant_translation_labels .field_language {
    margin-left: 0.5em;
}

.BackOfficeLayout .Form.grouped_translation_labels .field_language {
    display: block;
    margin-bottom: 0.3em;
}

.BackOfficeLayout .Form.grouped_translation_labels .field_instance-CheckBox .field_language {
    display: inline-block;
}

.BackOfficeLayout .Form .required_mark {
    font-weight: bold;
    color: rgb(100,125,150);
    padding-left: 0.3em;
}

.BackOfficeLayout .Form .field_instance-HiddenInput {
    display: none;
}

.BackOfficeLayout .Form .field_instance-CheckBox label {
    display: inline;
}

.BackOfficeLayout .Form .field_instance-CheckBox input {
    width: auto !important;
    margin-left: 0;
    margin-right: 0.4em;
}

.BackOfficeLayout .Form .control,
.BackOfficeLayout .Form .field_instance-DatePicker .time  {
    font-size: 90%;
}

.BackOfficeLayout .Form td .control,
.BackOfficeLayout .Form td .mceEditor .mceLayout,
.BackOfficeLayout .Form td .ItemSelector button {
    width: 100%;
}

.BackOfficeLayout .Form td .DatePicker {
    width: 8em;
    margin-right: 0.5em;
}

.BackOfficeLayout .ui-datepicker-trigger {
    margin-left: 0.3em;
    vertical-align: middle;
}

.BackOfficeLayout .DatePicker,
.BackOfficeLayout .field_instance .DatePicker.control {
    width: 8em;
}

.field_instance-DatePicker .time {
    margin-left: 0.9em;
    width: 6em;
}

.BackOfficeLayout .CollectionEditor .MoneyBox {
    display: inline-block;
    margin-right: 1em;
}


.BackOfficeEditView .ContentForm .RichTextEditor {
    display: inline-block;
}

/* DropdownPanel
-----------------------------------------------------------------------------*/
.scripted .DropdownPanel .dropdown_arrow {
    margin-left: 0.2em;
}

.scripted .DropdownPanel > .panel_wrapper > .panel {
    -moz-box-shadow: 3px 3px 7px #bbb;
    -webkit-box-shadow: 3px 3px 7px #bbb;
    box-shadow: 3px 3px 7px #bbb;
    border: 1px solid rgb(190,200,210);
    background-color: rgb(250,250,250);
    border-radius: 0;
    padding: 0.7em;
    overflow: hidden;
}

.scripted .DropdownPanel > .button {
    white-space: nowrap;
}

.scripted .DropdownPanel-expanded > .button,
.scripted .DropdownPanel-expanded > .button:hover {
    border: 1px solid rgb(190,200,210);
    border-radius: 0;
    border-bottom-color: rgb(250,250,250);
    background-color: rgb(250,250,250);
}

/* SearchableCheckList
-----------------------------------------------------------------------------*/
.SearchableCheckList .toggle_selection_links {
    margin: 0.5em 0;
}

.SearchableCheckList .toggle_selection_links a {
    font-size: 0.8em;
}

.SearchableCheckList .toggle_selection_links a[disabled] {
    opacity: 0.5;
    text-decoration: none;
}

.SearchableCheckList .toggle_selection_links .empty_selection_link {
    margin-left: 0.8em;
}

.BackOfficeLayout .SearchableCheckList.search_enabled .check_list {
    max-height: 24.8em;
    overflow: auto;
    padding: 0.5em;
    padding-right: 1em;
    border: 1px solid #ddd;
    background-color: white;
}

.BackOfficeLayout .SearchableCheckList.search_enabled.control .check_list {
    height: 15em;
}

/* Tables
-----------------------------------------------------------------------------*/

body.scripted .BackOfficeLayout .Table .row_selection_control {
    position: absolute;
    left: -10000px;
}

.BackOfficeLayout .Table,
.BackOfficeLayout .PropertyTable {
	clear: both;
    border-collapse: collapse;
    width: 100%;
}

.BackOfficeLayout .Table {
    border: 1px solid #d6d6d6;
}

.BackOfficeLayout .PropertyTable th {
    width: 25%;
}

.BackOfficeLayout .PropertyTable tr.group_header th {
    font-weight: bold;
}

.BackOfficeLayout .PropertyTable tbody + tbody tr.group_header th {
    padding-top: 2em;
}

.BackOfficeLayout .PropertyTable tr.member_row th {
    padding-left: 2em;
}

.BackOfficeLayout .Table th {
    border: 1px solid #ccc;
}

.BackOfficeLayout .Table th a {
    text-decoration: none;
}

.BackOfficeLayout .Table th,
.ObjectDiff th {
    background-position: bottom left;
    background-repeat: repeat-x;
    background-image: url(/resources/images/header.png);
    background-image: -webkit-linear-gradient(#eee, #d6d6d6);
    background-image: linear-gradient(#eee, #d6d6d6);
    background-color: #e0e0e0;
}

.BackOfficeLayout .ContentTable td,
.BackOfficeLayout .ContentTable td * {
    cursor: default;
}

.BackOfficeLayout .ContentTable .ItemLabel {
    display: inline-block;
}

.BackOfficeLayout .ContentTable th .column_dropdown > .button > .label {
    background-position: right 0.5em;
    white-space: nowrap;
}

.BackOfficeLayout .ContentTable th.last .column_dropdown > .panel_wrapper > .panel {
    left: auto;
    right: 0;
}

.BackOfficeLayout .ContentTable th .column_panel {
    min-width: 19em;
}

.BackOfficeLayout .ContentTable th .column_panel > div + div {
    margin-top: 1em;
}

.BackOfficeLayout .ContentTable th .column_panel .options_header {
    margin-bottom: 0.6em;
    padding-bottom: 0.2em;
    font-size: 0.9em;
    font-weight: bold;
    color: #555;
    border-bottom: 1px dotted #ccc;
}

.BackOfficeLayout .ContentTable th .column_panel > div > a + a {
    margin-top: 0.4em;
}

.BackOfficeLayout .ContentTable th .column_panel > div > a {
    display: block;
    background-repeat: no-repeat;
    background-position: 0 -2px;
    padding-left: 18px;
}

.BackOfficeLayout .ContentTable .sorting_options a.selected {
    font-weight: bold;
}

.BackOfficeLayout .ContentTable .sorting_options .ascending {
    background-image: url(/resources/images/ascending.png);
    _background-position:0 -2px;
    _background-repeat:no-repeat;
    _display:block;
    _padding-left:18px;
}

.BackOfficeLayout .ContentTable .sorting_options .descending {
    background-image: url(/resources/images/descending.png);
    _background-position:0 -2px;
    _background-repeat:no-repeat;
    _display:block;
    _padding-left:18px;
}

.BackOfficeLayout .ContentTable .search_options .add_filter {
    background-image: url(/resources/images/add.png);
    _background-position:0 -2px;
    _background-repeat:no-repeat;
    _display:block;
    _padding-left:18px;
}

.BackOfficeLayout .PropertyTable th {
    text-align: left;
    font-weight: normal;
}

.BackOfficeLayout .PropertyTable table.translated_values th {
    padding-left: 0;
    width: 8em;
    color: rgb(70,70,70);
}

.BackOfficeLayout .PropertyTable .type_header th {
    font-weight: bold;
    color: rgb(50,50,50);
    background-image: url(/resources/images/expanded_block.png);
    background-repeat: no-repeat;
    background-position: 0.3em center;
    padding-left: 1.5em;
    cursor: pointer;
}

.BackOfficeLayout .PropertyTable .type_group.collapsed .type_header th {
    background-image: url(/resources/images/collapsed_block.png);
    background-position: 0.6em center;
}

.BackOfficeLayout .PropertyTable .type_group.collapsed tbody {
    display: none;
}

.BackOfficeLayout .PropertyTable .member_entry th {
    width: 18em;
    padding-left: 2.4em;
}

.BackOfficeLayout .Table th, .BackOfficeLayout .Table th * {
    font-weight: normal;
    color: black;
}

.BackOfficeLayout .Table th span.label {
    color: rgb(75,75,75);
}

.BackOfficeLayout .Table th,
.BackOfficeLayout .Table td,
.BackOfficeLayout .PropertyTable th,
.BackOfficeLayout .PropertyTable td {
    vertical-align: top;
	text-align: left;
	padding: 0.5em;
    font-size: 85%;
}

.BackOfficeLayout .ContentTable ul,
.BackOfficeLayout .PropertyTable ul {
    padding: 0;
    margin: 0;
    list-style-type: none;
    list-style-position: inside;
}

.BackOfficeLayout .ContentTable li,
.BackOfficeLayout .PropertyTable li {
    padding: 0;
    margin: 0;
}

.BackOfficeLayout .ContentTable ul ul,
.BackOfficeLayout .PropertyTable ul ul {
    padding-left: 2em;
}

.BackOfficeLayout .ContentTable li,
.BackOfficeLayout .PropertyTable li {
    margin-bottom: 0.5em;
}

/*.Table tr.translations th {*/
.BackOfficeLayout .Table th .translation {
    margin-left: 0.5em;
    font-size: 80%;
    font-weight: normal;
    font-style: italic;
    color: rgb(75,75,75);
    padding-top: 0;
}

.BackOfficeLayout .Table .selection {
    width: 1.5em;
    padding-right: 0;
}

.BackOfficeLayout .even {
	background-color: rgb(245,245,245);
}

.BackOfficeLayout .odd {
    background-color: white;
}

.BackOfficeLayout .Table tr.group td {
    color: rgb(70,70,70);
    text-align: right;
    background-image: -webkit-linear-gradient(#eee,#d5d5d5);
    background-image: -moz-linear-gradient(#eee,#d5d5d5);
    background-image: linear-gradient(#eee,#d5d5d5);
    background-color: #eee;
    border-top: 1px solid #bbb;
    border-bottom: 1px solid #bbb;
}

.BackOfficeLayout .Table tr.group .grouping_value {
    float: left;
    font-weight: bold;
    margin-right: 0.5em;
}

.BackOfficeLayout .Table tr.group .grouping_member {
    float: left;
    font-style: italic;
    font-size: 90%;
}

.BackOfficeLayout .Table tr.group .remove_grouping {
    font-size: 85%;
}

.BackOfficeLayout .Table th .grouping_options table {
    border-collapse: collapse;
}

.BackOfficeLayout .Table th .grouping_options table * {
    font-size: 100%;
}

.BackOfficeLayout .Table th .grouping_options table td {
    border: none;
}

.BackOfficeLayout .Table th .grouping_options td.variant {
    white-space: nowrap;
}

.BackOfficeLayout .Table th .grouping_options .sign a {
    text-decoration: underline;
}

.BackOfficeLayout .Table th.sorted span.label {
    font-weight: bold;
}

.BackOfficeLayout .Table tr.selected td {
    background-color: #777 !important;
}


.BackOfficeLayout .Table.focused tr.selected td {
    background-color: #4b4b4b !important;
}

.BackOfficeLayout .Table tr.selected td,
.BackOfficeLayout .Table tr.selected td * {
    color: white !important;
}

.BackOfficeLayout .changed,
.BackOfficeItemView .tab.changed {
    background-color: rgb(250,242,190);
}

.BackOfficeItemView h2 {
    font-size: 1em;
    font-weight: normal;
    line-height: 1.2em;
    margin-left: 0.5em;
}

.BackOfficeItemView h2 .item_icon {
    margin-right: 0.8em;
    display: inline-block;
    vertical-align: top;
}

.BackOfficeItemView h2 .item_info {
    display: inline-block;
    vertical-align: top;
}

.BackOfficeItemView h2 .item_translation {
    font-size: 1.1em;
    font-weight: bold;
    margin-bottom: 0.2em;
}

.BackOfficeItemView h2 .item_info > span {
    font-size: 0.9em;
    margin-right: 0.3em;
    color: #333;
    vertical-align: top;
}

.BackOfficeItemView h2 .item_path {
    vertical-align: top;
    display: inline-block;
}

.BackOfficeItemView h2 .item_references {
    margin-top: 0.3em;
    margin-left: -4px;
    display: block;
}

.BackOfficeItemView h2 .item_references .panel_wrapper .panel {
    padding: 0.5em;
    min-width: 13em;
}

.BackOfficeItemView h2 .item_info .file_size,
.BackOfficeItemView h2 .item_info .file_mime_type {
    color: #666;
}

.BackOfficeLayout .changed {
    outline: 1px solid #EBE3AF;
}

.BackOfficeLayout .Table td.element_column label {
    padding-top: 0;
    padding-bottom: 0;
}

.BackOfficeLayout .search_results_message {
    clear: both;
    font-size: 85%;
    font-weight: bold;
    color: rgb(50,50,50);
    margin-top: 0.75em;
    margin-bottom: 0.75em;
}

.BackOfficeLayout .expansion_controls {
    float: left;
    padding-left: 0.6em;
    padding-bottom: 0.5em;
    font-size: 75%;
}

.BackOfficeLayout .expansion_controls * {
    padding-right: 1em;
    text-decoration: none;
}

.BackOfficeLayout .Table .position_mark button {
    font-size: 85%;
}

.BackOfficeLayout .Table .List {
    margin: 0;
    padding: 0;
    list-style-position: inside;
}

.BackOfficeLayout .forbidden {
    color: rgb(135,35,10) !important;
}

.BackOfficeLayout .Table a.target-focus {
    position: absolute;
    left: -100px;
}

.BackOfficeLayout .TranslationDisplay.inherited_translation {
    opacity: 0.6;
}

/* Toolbar
-----------------------------------------------------------------------------*/

.BackOfficeLayout .data_controls {
    padding-top: 0.6em;
    float: right;
}

.BackOfficeLayout .toolbar,
.BackOfficeLayout .toolbar_box {
	clear: both;
    margin-top: 1em;
	background-color: #f2f0eb;
	border: 1px solid #dcd9d0;
}

.BackOfficeLayout .toolbar_box {
    height: 2.2em;
}

.BackOfficeLayout .toolbar {
    height: 1.8em;
    padding: 0.2em 0.6em;
}

.BackOfficeLayout .toolbar_box .toolbar {
    float: left;
    margin: 0;
    border: none;
    background-color: transparent;
    height: auto;
    padding: 0.2em;
}

.BackOfficeLayout .toolbar .action_button,
.BackOfficeLayout .toolbar .additional_actions_selector {
    float: left;
	font-size: 85%;
    margin: 0;
    margin-top: 0.1em;
    padding: 0;
}

.BackOfficeLayout .toolbar * + .action_button,
.BackOfficeLayout .toolbar * + .additional_actions_selector {
    margin-left: 1.5em;
}

.BackOfficeLayout .toolbar .DropdownPanel + .action_button,
.BackOfficeLayout .toolbar .DropdownPanel + .additional_actions_selector {
    margin-left: 0.7em;
}

.BackOfficeLayout .toolbar .additional_actions_selector .action_button {
    margin-left: 0 !important;
}

.BackOfficeLayout .toolbar a {
    text-decoration: none;
}

.BackOfficeLayout .toolbar a.action_button {
    padding: 0.25em 0;
    color: black;
}

.BackOfficeLayout .toolbar .action_button .label,
.BackOfficeLayout .toolbar .additional_actions_selector .label {
    display: block;
    height: 1.8em;
    padding-top: 0.2em;
}

.BackOfficeLayout .toolbar .action_button.DropdownPanel .label {
    display: inline;
}

.BackOfficeLayout .toolbar button.action_button {
    border: none;
    background: none;
    padding-top: 0.2em;
    cursor: pointer;
    color: black;
}

.BackOfficeLayout .toolbar .action_button img {
	vertical-align: middle;
    margin-right: 0.3em;
}

.BackOfficeLayout .toolbar .new_toolbar_button {
    font-size: 100%;
}

.BackOfficeLayout .toolbar .new_toolbar_button > .button > .label {
    font-size: 85%;
}

.BackOfficeLayout .toolbar .additional_actions_selector .selector_content {
    width: 16em;
}

.BackOfficeLayout .toolbar .additional_actions_selector .selector_content .action_button {
    display: block;
    float: none;
    font-size: 100%;
    padding: 0.2em 0;
}

.BackOfficeLayout .action_button[disabled] {
    opacity: 0.3;
}

.BackOfficeLayout .selector_content label {
    display: inline;
}

/* Collection settings
-----------------------------------------------------------------------------*/
.BackOfficeLayout .CollectionView .collection_settings {
    white-space: nowrap;
}

.BackOfficeLayout .CollectionView .collection_settings > * {
    display: inline-block;
    vertical-align: middle;
}

.BackOfficeLayout .CollectionView .collection_settings > * + * {
    margin-left: 1.5em !important;
}

.BackOfficeLayout .CollectionView .collection_settings .DropdownPanel > .button > .label {
    font-size: 1em;
    vertical-align: middle;
    height: 18px;
}

.BackOfficeLayout .CollectionView .collection_settings .DropdownPanel .panel {
    text-align: left;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
}

.BackOfficeLayout .DropdownPanel .panel .SearchableCheckList .search_controls {
    margin-bottom: 0.5em;
}

.BackOfficeLayout .DropdownPanel .panel .SearchableCheckList .search_box {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    width: 100%;
}

.BackOfficeLayout .DropdownPanel .panel .SearchableCheckList .check_list label {
    font-size: 0.8em;
}

.BackOfficeLayout .CollectionView .collection_settings .members_dropdown .check_list .group_label {
    font-size: 0.8em;
    color: #555;
    border-bottom: 1px dotted #ccc;
    padding-bottom: 0.2em;
    margin-bottom: 0.2em;
}

.BackOfficeLayout .CollectionView .collection_settings .members_dropdown .check_list .group:first-child .group_label {
    display: none;
}

.BackOfficeLayout .DropdownPanel .panel .box_buttons {
    margin-top: 0.5em;
}

.BackOfficeLayout .DropdownPanel .panel .box_buttons button {
    margin: 0;
}

.BackOfficeLayout .CollectionView .collection_display_container {
    clear: both;
    position: relative;
    overflow: visible;
    min-width: 100%;
    display: inline-block;
}

/* Content type selector
-----------------------------------------------------------------------------*/
.BackOfficeLayout .content_type_selector > .button > .label {
    font-size: 85%;
}

/* Content view dropdown
-----------------------------------------------------------------------------*/
.BackOfficeLayout .collection_settings .content_view_list {
    list-style-type: none;
    margin: 0;
    padding: 0;
}

.BackOfficeLayout .collection_settings .content_view_entry {
    display: block;
    padding: 0.3em 0;
}

.BackOfficeLayout .collection_settings .content_view_entry a {
    font-size: 0.8em;
    text-decoration: none;
    color: #333;
}

.BackOfficeLayout .collection_settings .content_view_entry.selected a {
    font-weight: bold;
}

/* Dropdown selector
-----------------------------------------------------------------------------*/
.BackOfficeLayout .selector {
    position: relative;
    overflow: visible;
    cursor: default;
}

.BackOfficeLayout .selector > .label {
    position: relative;
    padding-left: 0.2em;
    padding-right: 1em;
    background: url(/resources/images/dropdown_arrow.png) no-repeat right 0.7em;
    border: 1px solid transparent;
    z-index: 2;
    cursor: pointer;
    color: black;
}

.BackOfficeLayout .selector:hover > .label,
body.scripted .BackOfficeLayout .selector.unfolded > .label,
body.scripted .BackOfficeLayout .selector.unfolded:hover > .label {
    background-color: rgb(250,250,250);
    border: 1px solid rgb(190,200,210);
    border-bottom-color: rgb(250,250,250);
    z-index: 1001;
}

body.scripted .BackOfficeLayout .selector:hover > .label {
    border-color: transparent;
    background-color: transparent;
}

.BackOfficeLayout .selector_content {
    display: none;
    min-width: 8em;
    position: absolute;
    top: 2.1em;
    border: 1px solid rgb(190,200,210);
    background-color: rgb(250,250,250);
    padding: 0.4em 0.6em;
    margin: 0;
    z-index: 1;
    padding: 0.6em;
    -moz-box-shadow: 3px 3px 7px #bbb;
    -webkit-box-shadow: 3px 3px 7px #bbb;
    box-shadow: 3px 3px 7px #bbb;
}

.BackOfficeLayout .selector:hover .selector_content,
body.scripted .BackOfficeLayout .selector.unfolded .selector_content,
body.scripted .BackOfficeLayout .selector.unfolded:hover .selector_content {
    display: block;
    z-index: 1000;
}

body.scripted .BackOfficeLayout .selector:hover .selector_content {
    display: none;
}

/* Link selectors
-----------------------------------------------------------------------------*/
.BackOfficeLayout .LinkSelector .selected {
    font-weight: bold;
}

/* Content type dropdown
-----------------------------------------------------------------------------*/
.BackOfficeLayout .ContentTypeTree,
.BackOfficeLayout .ContentTypeTree ul,
.BackOfficeLayout .ContentTypeTree li {
    padding-left: 0;
    padding-top: 0;
    padding-bottom: 0;
    margin: 0;
    list-style-type: none;
}

.BackOfficeLayout .ContentTypeTree li {
    padding-top: 0.8em;
    white-space: nowrap;
}

.BackOfficeLayout .ContentTypeTree li li {
    padding-left: 2em;
}

.BackOfficeLayout .ContentTypeTree .entry_label {
    padding-bottom: 0.2em;
    color: black;
}

.BackOfficeLayout .ContentTypeTree .icon,
.BackOfficeLayout .ItemLabel .icon {
    position: relative;
    top: -0.1em;
    vertical-align: middle;
    margin-right: 0.4em;
}

/* Content type selector
-----------------------------------------------------------------------------*/
.BackOfficeLayout .ContentTypeSelector > .button > .label {
    display: inline-block;
}

.BackOfficeLayout .ContentTypeSelector > .button > .label > * {
    vertical-align: middle;
}

.BackOfficeLayout .ContentTypeSelector > .button > .label > img {
    margin-right: 0.4em;
}

.BackOfficeLayout .ContentTypeSelector .palette > .palette_group > .nested_groups {
    display: table;
}

.BackOfficeLayout .ContentTypeSelector .palette > .palette_group > .nested_groups > .palette_group {
    display: table-cell;
    padding-right: 1.5em;
    padding-top: 0;
    vertical-align: top;
}

.BackOfficeLayout .ContentTypeSelector .palette > .palette_group > .nested_groups > .palette_group > .group_label,
.BackOfficeLayout .ContentTypeSelector .palette .palette_group:first-child > .group_label {
    margin-top: 0;
}

.BackOfficeLayout .ContentTypeSelector .palette .palette_group.with_label .palette_group .group_label {
    margin-top: 1.2em;
}

.BackOfficeLayout .ContentTypeSelector .palette > .palette_group > .nested_groups > .palette_group + .palette_group {
    padding-left: 1.5em;
    border-left: 1px solid #ddd;
}

.BackOfficeLayout .ContentTypeSelector .palette > .palette_group > .nested_groups > .palette_group:last-child {
    padding-right: 0;
}

.BackOfficeLayout .ContentTypeSelector .palette_entry + .palette_entry {
    margin-top: 0.5em;
}

.BackOfficeLayout .ContentTypeSelector a {
    color: #333;
    font-size: 0.9em;
}

.BackOfficeLayout .ContentTypeSelector .selected a {
    font-weight: bold;
}

/* Content type picker
-----------------------------------------------------------------------------*/
.BackOfficeLayout .ContentTypePicker {
    clear: left;
    border: 1px solid #ccc;
    background-color: #eee;
    margin-top: 2.4em;
    padding: 0.4em;
}

.BackOfficeLayout .ContentTypePicker > li:first-child {
    padding-top: 0;
}

.BackOfficeLayout .ContentTypePicker .label {
    display: block;
    padding: 0.5em 0.2em;
}

.BackOfficeLayout .ContentTypePicker .entry_label {
    display: inline;
}

.scripted .BackOfficeLayout .ContentTypePicker ul {
    display: none;
}

.scripted .BackOfficeLayout .ContentTypePicker ul .empty_item {
    padding-left: 3.6em;
}

.scripted .BackOfficeLayout .ContentTypePicker .toggle_button {
    margin-right: 0.4em;
    position: relative;
    top: 0.2em;
}

.scripted .BackOfficeLayout .ContentTypePicker label {
    padding: 0.2em;
    -webkit-border-radius: 0.3em;
    -moz-border-radius: 0.3em;
}

.scripted .BackOfficeLayout .ContentTypePicker label.selected {
    color: white;
    font-weight: bold;
    background-color: rgb(75,75,75);
}

.scripted .BackOfficeLayout .ContentTypePicker input {
    display: none;
}

.scripted .BackOfficeLayout .ContentTypePickerDropdown {
    margin-top: 0.4em;
}

.scripted .BackOfficeLayout .ContentTypePickerDropdown .button .label .icon {
    vertical-align: middle;
    margin-right: 0.4em;
}

.scripted .BackOfficeLayout .ContentTypePickerDropdown .panel {
    width: 32em;
}

.scripted .BackOfficeLayout .ContentTypePickerDropdown .content_type_picker {
    margin: 0;
    padding: 0;
    border: none;
}

/* Paging
-----------------------------------------------------------------------------*/

.BackOfficeLayout .PagingControls {
    float: right;
    padding-right: 0.5em;
}

.BackOfficeLayout .item_count,
.BackOfficeLayout .page_size,
.BackOfficeLayout .Pager {
    float: right;
    font-size: 85%;
    margin-left: 2em;
}

.BackOfficeLayout .page_size input {
    font-size: inherit;
    width: 2.5em;
    margin-left: 0.4em;
}

.BackOfficeLayout .Pager * {
    float: left;
    display: block;
}

.BackOfficeLayout .Pager .previous {
    margin-left: 0.3em;
}

.BackOfficeLayout .Pager .next {
    margin-right: 0.3em;
}

.BackOfficeLayout .Pager .page_links {
    margin-left: 0.8em;
    margin-right: 0.8em;
}

.BackOfficeLayout .Pager .page_links a + a {
    margin-left: 0.5em;
}

.BackOfficeLayout .Pager .page_links a.selected {
    font-weight: bold;
}

.BackOfficeLayout .no_results {
    border: 1px dotted rgb(200,160,120);
    padding: 0.5em;
}

/* Tree content view
-----------------------------------------------------------------------------*/

.BackOfficeLayout .TreeContentView .expander {
    margin-left: -0.1em;
    float: left;
}

.BackOfficeLayout .TreeContentView .expander + label {
    margin-left: 0.3em;
}

.BackOfficeLayout .TreeContentView .expander img {
    vertical-align: middle;
}

.BackOfficeLayout .TreeContentView .depth_level {
    padding-left: 1.8em;
}

.BackOfficeLayout .TreeContentView .leaf label {
    margin-left: 1.5em;
}

.BackOfficeLayout .TreeContentView tr.filtered .element_column {
    color: rgb(120,120,120);
    font-style: italic;
}

/* Thumbnails content view
-----------------------------------------------------------------------------*/
.BackOfficeLayout .ThumbnailsContentView .collection_display {
    padding-bottom: 0.5em;
    border: 1px solid #d6d6d6;
    background-color: #fcfcfc;
}

.BackOfficeLayout .ThumbnailsContentView .collection_display .entry {
    display: inline-block;
    vertical-align: bottom;
    margin: 1em;
    text-align: center;
}

body.scripted .BackOfficeLayout .ThumbnailsContentView .collection_display input[type=checkbox] {
    position: absolute;
    left: -10000px;
}

.BackOfficeLayout .ThumbnailsContentView .collection_display label {
    display: inline-block;
    margin-top: 0.5em;
    padding: 0.2em 0.5em;
    white-space: normal;
    font-size: 85%;
}

.BackOfficeLayout .ThumbnailsContentView .collection_display .selected label {
    background-color: #777;
    color: white;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
}

.BackOfficeLayout .ThumbnailsContentView .collection_display.focused .selected label {
    background-color: #4b4b4b;
}

/* Changelog
-----------------------------------------------------------------------------*/
.BackOfficeChangeLogView .id_column {
    width: 5em;
}

.BackOfficeChangeLogView .author_column {
/*    width: 24em;*/
}

.BackOfficeChangeLogView .date_column {
    width: 12em;
}

.BackOfficeChangeLogView .action_column {
    width: 8em;
}

.BackOfficeChangeLogView .changes_column li {
    padding: 0;
    margin: 0;
}

.BackOfficeChangeLogView .changes_column li + li {
    margin-top: 0.4em;
}

.BackOfficeChangeLogView td.changes_column.collapsed ul {
    display: none;
}

.BackOfficeChangeLogView td.changes_column.expanded ul {
    margin-bottom: 0.4em;
}

.BackOfficeChangeLogView td.action_column.create_action {
    color: rgb(15,125,15);
}

.BackOfficeChangeLogView td.action_column.modify_action {
    color: rgb(145,110,15);
}

.BackOfficeChangeLogView td.action_column.delete_action {
    color: rgb(150,0,0);
}

.BackOfficeChangeLogView td.create_action {
    background-color: rgb(230,245,230);
}

.BackOfficeChangeLogView td.modify_action {
    background-color: rgb(250,245,205);
}

.BackOfficeChangeLogView td.delete_action {
    background-color: rgb(240,220,200);
}

/* Notifications
-----------------------------------------------------------------------------*/
.BackOfficeLayout .notification_box {
    margin: 0.8em;
}

.BackOfficeLayout .notification {
    padding: 0.4em;
}

.BackOfficeLayout .notification .close_button {
    float: right;
    cursor: pointer;
}

.BackOfficeLayout .notification + .notification {
    margin-top: 0.4em;
}

.BackOfficeLayout .success {
    border: 1px solid rgb(200,220,200);
    background-color: rgb(220,240,220);
}

.BackOfficeLayout .success strong,
.BackOfficeLayout .success em {
    color: rgb(20,80,20);
    font-weight: bold;
    font-style: normal;
}

.BackOfficeLayout .notice {
    border: 1px solid rgb(220,210,190);
    background-color: rgb(240,240,210);
    padding: 0.4em;
    margin-bottom: 1em;
}

.BackOfficeLayout .item_info_panel {
    background-color: #eee;
    border: 1px solid #ccc;
    padding: 0.5em;
}

.preview-error-box,
.BackOfficeLayout .ErrorBox,
.BackOfficeLayout .error_box,
.BackOfficeLayout .notification_box .error,
.BackOfficeInstallationSyncView .sync_request_error_report {
    color: black;
    border: 1px dotted rgb(200,160,120);
    background-color: rgb(245,230,215);
    padding: 0.5em;
    margin: 1em 0;
}

.preview-error-box {
    color: black;
    border: 1px dotted rgb(200,160,120);
    background-color: rgb(245,230,215);
    padding: 0.5em;
    margin: 0 1em 1em 1em;
}

.BackOfficeLayout .ErrorBox li,
.BackOfficeLayout .error_box li {
    list-style-type: none;
}

.BackOfficeLayout .error_box li + li {
    margin-top: 0.2em;
}

.BackOfficeLayout .notification_box .error em,
.BackOfficeLayout .error_box li em {
    font-style: normal;
    font-weight: bold;
    color: rgb(135,35,10);
}

.BackOfficeLayout .field .error {
    border: 1px solid rgb(200,160,120) !important;
    background-color: rgb(245,230,215) !important;
}

/* Detail view
-----------------------------------------------------------------------------*/
.BackOfficeShowDetailView .PropertyTable {
    margin-top: 1.5em;
}

.BackOfficeShowDetailView .PropertyTable .thumbnail_list {
    list-style-type: none;
    padding: 0;
    margin: 0;
}

.BackOfficeShowDetailView .PropertyTable .thumbnail_list li {
    padding: 0;
    margin-left: 0;
    margin-top: 1em;
    margin-bottom: 1em;
    margin-right: 2em;
    display: block;
    float: left;
}

.BackOfficeShowDetailView .PropertyTable .resource_thumbnail {
    text-align: center;
    width: 10em;
}

.BackOfficeShowDetailView .PropertyTable .resource_thumbnail a {
    text-decoration: none;
}

.BackOfficeShowDetailView .PropertyTable .resource_thumbnail a.thumbnail_link {
    display: block;
    text-align: center;
    margin-bottom: 0.8em;
}

.BackOfficeShowDetailView .PropertyTable .resource_thumbnail a.thumbnail_link .thumbnail {
    display: block;
    margin: auto;
    margin-bottom: 0.4em;
}

.BackOfficeShowDetailView .PropertyTable .resource_thumbnail a.thumbnail_link .label {
    text-decoration: underline;
}

.BackOfficeShowDetailView .PropertyTable .resource_thumbnail a.open_resource_link {
    color: rgb(70,70,70);
    font-size: 90%;
    background-repeat: no-repeat;
    background-image: url(/resources/images/open_resource.png);
    background-position: left center;
    padding-left: 0.7em;
    padding-top: 0.2em;
    padding-bottom: 0.2em;
}

/* Edit form
-----------------------------------------------------------------------------*/
.BackOfficeItemView .toolbar .action_button.selected {
    font-weight: bold;
    color: rgb(50,50,50);
}

.BackOfficeLayout .toolbar .preview_action,
.BackOfficeLayout .toolbar .save_action,
.BackOfficeLayout .toolbar .save_and_close_action,
.BackOfficeLayout .toolbar .close_action,
.BackOfficeLayout .toolbar .cancel_action {
    float: right;
    margin-left: 1em;
    margin-right: 0;
}

.BackOfficeItemView .navigation .section_entry {
    z-index: 1;
    margin-left: 0;
    margin-right: 0.2em;
}

.BackOfficeItemView .messages {
    margin-bottom: 0.3em;
}

.BackOfficeItemView .edit_form_frame {
    border: 1px solid rgb(200,210,220);
    border-top: none;
    z-index: 0;
    clear: both;
    position: absolute;
    top: 2.5em;
    bottom: 4em;
    left: 0;
    right: 0;
    overflow: auto;
}

.BackOfficeItemView .edit_form {
    padding: 0;
}

.BackOfficeEditView .success {
    margin-bottom: 1em;
}

.BackOfficeEditView .edit_form .fields {
    clear: both;
}

.BackOfficeItemView .edit_form_toolbar {
    border-bottom: 1px solid rgb(230,235,240);
    height: 2em;
    padding-top: 0.3em;
    padding-right: 0.3em;
}

.BackOfficeLayout .ItemSelector {
    padding: 0.1em;
}

.BackOfficeLayout .ItemSelector .selection_label,
.BackOfficeLayout .ItemSelector-buttons {
    display: inline-block;
}

.BackOfficeLayout .ItemSelector .selection_label {
    margin-top: 0.05em;
    margin-right: 1.4em;
}

.BackOfficeLayout .ItemSelector .selection_label:empty {
    margin-right: 0;
}

.BackOfficeFieldsView .ItemSelector-button {
    margin-right: 0.6em;
}

.BackOfficeFieldsView button.ItemSelector-button,
.BackOfficeFieldsView .ItemSelector .new .label {
    font-size: 90%;
}

.BackOfficeFieldsView .ItemSelector-button .icon {
    vertical-align: middle;
    margin-right: 0.3em;
}

.BackOfficeFieldsView .ItemSelector .new {
    margin-left: -0.4em;
}

.BackOfficeFieldsView .ItemSelector .new .label {
    color: rgb(50,80,110);
    padding-left: 0.4em;
    padding-top: 0.2em;
}

.BackOfficeFieldsView .ItemSelector .new .selector_content {
    top: 1.2em;
}

.BackOfficeFieldsView .ItemSelector .new .selector_content .entry_label {
    border: none;
    background: none;
    font-size: 95%;
    cursor: pointer;
}

.BackOfficeLayout .filters .ItemSelector .selection_label {
    margin-top: 0.3em;
}

.BackOfficeLayout .filters .ItemSelector .select .icon {
    display: none;
}

.BackOfficeFieldsView .ItemSelector button,
button.TypeSelectorButton {
    text-align: left;
}

.BackOfficeLayout .ItemSelector .selection_label {
    background-repeat: no-repeat;
    color: rgb(75,75,75);
}

.BackOfficeLayout .ItemSelector .empty_selection,
button.TypeSelectorButton span {
    padding-left: 0;
    font-style: italic;
}

.BackOfficeItemView .buttons .additional_actions_selector .selector_content button {
    display: block;
    padding: 0;
    margin: 0;
    text-align: left;
    border: none;
    background-color: rgb(250, 250, 250);
}

.BackOfficeItemView .additional_actions_selector .selector_content button + button {
    margin-top: 0.3em;
}

.BackOfficeEditView .edit_form {
    padding-top: 0.8em;
}

.BackOfficeFieldsView .ContentView {
    border: 1px solid rgb(210,210,210);
    background-color: white;
    padding: 0.6em;
}

.BackOfficeLayout .autocomplete_results_container {
    overflow: visible;
    position: relative;
}

.BackOfficeLayout .autocomplete_dropdown {
    display: none;
    position: absolute;
    top: 0;
    left: 0;
    border: 1px solid rgb(190,200,210);
    background-color: rgb(250,250,250);
    font-size: 0.8em;
    width: auto;
    max-height: 24em;
    overflow: auto;
}

.BackOfficeLayout .autocomplete_dropdown.unfolded {
    display: block;
}

.BackOfficeLayout .autocomplete_dropdown div {
    padding: 0.4em;
    white-space: nowrap;
    cursor: pointer;
}

.BackOfficeLayout .autocomplete_dropdown .highlighted,
.BackOfficeLayout .autocomplete_dropdown div:hover {
	background-color: Highlight;
	color: HighlightText;
}

/* ItemTranslationsSelector
-----------------------------------------------------------------------------*/
.BackOfficeItemView .translations_dropdown {
    float: right;
    padding-top: 0.5em;
}

.BackOfficeItemView .translations_dropdown > .panel_wrapper > .panel {
    left: auto;
    right: 0;
}

.ItemTranslationsSelector {
    display: inline-block;
    white-space: nowrap;
}

.ItemTranslationsSelector .search_controls {
    margin-bottom: 0.5em;
}

.ItemTranslationsSelector .search_box {
    width: 12em;
}

.ItemTranslationsSelector .available_languages_section,
.ItemTranslationsSelector .defined_languages_section {
    display: inline-block;
    width: 18em;
}

.ItemTranslationsSelector .available_languages_section {
    margin-left: 0.3em;
}

.ItemTranslationsSelector .available_languages_section > .heading,
.ItemTranslationsSelector .defined_languages_section > .heading {
    font-weight: bold;
    font-size: 0.9em;
    color: white;
    background-color: #605f5d;
    border: 1px solid #5f5742;
    padding: 0.2em 0.8em;
}

.ItemTranslationsSelector .toolbar {
    margin-top: 0;
    margin-bottom: -1px;
    height: auto;
}

.ItemTranslationsSelector .toolbar button {
    padding: 0;
    border: none;
    box-shadow: none;
    background-image: none;
    background-color: transparent;
    cursor: pointer;
    font-size: 0.8em;
}

.ItemTranslationsSelector .toolbar button + button {
    margin-left: 1em;
}

.ItemTranslationsSelector .language_list {
    height: 20em;
    overflow: auto;
    border: 1px solid #e5e5e5;
    background-color: white;
}

.ItemTranslationsSelector .language_list .entry label {
    display: block;
    margin: 0 !important;
    padding: 0.3em 0.8em;
    font-size: 0.9em;
    color: #333;
}

.ItemTranslationsSelector .available_languages_section .language_list .entry label {
     color: #777;
}

.ItemTranslationsSelector .language_list .entry.visible_translation label {
    font-weight: bold;
}

.ItemTranslationsSelector .language_list .entry input[type=checkbox] {
    position: absolute;
    left: -10000px;
}

.ItemTranslationsSelector .language_list .entry.selected {
    background-color: #aba2a2;
}

.ItemTranslationsSelector .language_list.focused .entry.selected {
    background-color: #8c8383;
}

.ItemTranslationsSelector .language_list .entry.selected label {
    color: white;
}

.ItemTranslationsSelector .selection_controls {
    margin-top: -1px;
    background-color: #ecebea;
    border: 1px solid #dcd9d0;
    padding: 0.1em 0.2em 0.3em 0.8em;
}

.ItemTranslationsSelector .selection_controls > * {
    font-size: 0.8em;
}

.ItemTranslationsSelector .selection_controls a {
    margin-left: 0.3em;
}

/* Order view
-----------------------------------------------------------------------------*/
.BackOfficeOrderView tr.original_position td.element_column {
    font-style: italic;
    color: rgb(75,75,75);
}

/* Move view
-----------------------------------------------------------------------------*/
.BackOfficeMoveView .tree li {
    list-style-type: none;
    margin-top: 0.7em;
}

.BackOfficeMoveView .tree .ItemLabel {
    padding-left: 1.3em;
}

.BackOfficeMoveView .tree .slot button {
    cursor: pointer;
    border: none;
    background: none;
    position: relative;
    left: -0.2em;
    display: block;
    margin: 0;
    padding: 0.1em 0;
    text-align: left;
}

.BackOfficeMoveView .tree .slot .label {
    font-size: 80%;
    color: rgb(50,80,110);
}

.BackOfficeMoveView .tree .slot_content {
    display: none;
}

.BackOfficeMoveView .tree .slot button:hover {
    border: 1px solid rgb(170,185,200);
    background-color: rgb(230,235,240);
    left: -0.3em;
    padding-bottom: 0;
}

.BackOfficeMoveView .tree .slot button:hover .label {
    display: none;
}

.BackOfficeMoveView .tree .slot .ItemLabel + .ItemLabel {
    margin-top: 0.8em;
}

.BackOfficeMoveView .tree .slot button:hover .ItemLabel {
    padding-left: 1.5em;
}

.BackOfficeMoveView .tree .slot button:hover .slot_content {
    display: block;
}

.BackOfficeMoveView .original_position {
    color: rgb(100,100,100);
}

/* Filter box
-----------------------------------------------------------------------------*/
.BackOfficeLayout .simple_search {
    float: right;
    height: 3em;
    position: relative;
}

.BackOfficeLayout .simple_search input[type=search] {
    margin: 0;
}

.BackOfficeLayout .filters {
    clear: both;
}

.BackOfficeLayout .ContentView .search_input {
    margin-right: 0.3em;
}

.BackOfficeLayout .ContentView .advanced_search {
    text-decoration: underline;
    font-size: 70%;
    background-image: url(/resources/images/collapsed_block.png);
    background-repeat: no-repeat;
    background-position: 0 center;
    margin-left: 1em;
    padding-left: 0.8em;
}

.BackOfficeLayout .CollectionView .filters {
    font-size: 85%;
    margin-top: 1em;
    border: 1px solid #ccc;
    background-color: #eee;
    padding: 0.5em;
}

.BackOfficeLayout .CollectionView .filters .filters_label {
    padding-bottom: 0.2em;
    color: #333;
    font-weight: bold;
    border-bottom: 1px solid #ddd;
}

.BackOfficeLayout .CollectionView .filters .FilterBox {
    padding-top: 1em;
}

.BackOfficeLayout .FilterBox .filter_entry {
    clear: left;
}

.BackOfficeLayout .FilterBox .filter_entry .field {
    margin-bottom: 0;
}

.BackOfficeLayout .FilterBox .filter_entry .filter_desc,
.BackOfficeLayout .FilterBox .filter_entry .filter_ui,
.BackOfficeLayout .FilterBox .filter_entry .fields,
.BackOfficeLayout .FilterBox .filter_entry .field,
.BackOfficeLayout .FilterBox .filter_entry .field_instance {
    clear: none !important;
    float: left !important;
}

.BackOfficeLayout .FilterBox .filter_entry fieldset {
    margin: 0;
    padding: 0;
}

.BackOfficeLayout .FilterBox .deleteButton {
    position: relative;
    top: 0.5em;
    font-size: 0.8em;
}

.BackOfficeLayout .CollectionView .filters .filter_desc {
    min-width: 10em;
    margin-top: 0.3em;
    margin-right: 1em;
}

.BackOfficeLayout .FilterBox .filter_entry .language_field .control {
    width: 12em;
}

.BackOfficeLayout .FilterBox .operator_field .control {
    width: 10em;
}

.BackOfficeLayout .CollectionView .filters .buttons {
    padding: 0;
}

.BackOfficeLayout .CollectionView .filters:not(.empty) .buttons {
    margin-top: 2em;
}

.BackOfficeLayout .CollectionView .filters .buttons button {
    width: auto;
}

.BackOfficeLayout .CollectionView .filters .ItemSelector button,
button.TypeSelectorButton {
    font-size: 95%;
}

.BackOfficeLayout .CollectionView .filters .discard_button {
    padding-left: 1.6em;
    background-repeat: no-repeat;
    background-position: left center;
    background-image: url(/resources/images/clear.png);
}

.BackOfficeLayout .CollectionView .filters .discard_button,
.BackOfficeLayout .CollectionView .filters .new_filter_selector {
    float: left;
    margin-top: 0.5em;
}

.BackOfficeLayout .CollectionView .filters .new_filter_selector {
    margin-right: 1em;
    margin-left: -0.4em;
}

.BackOfficeLayout .CollectionView .filters .new_filter_selector > .button {
    padding: 0.4em 0.3em;
}

.BackOfficeLayout .CollectionView .filters .new_filter_selector > .button > .label {
    padding-left: 1.6em !important;
    background-position: left center;
    background-image: url(/resources/images/add.png);
    background-repeat: no-repeat;
}

.BackOfficeLayout .CollectionView .filters .new_filter_selector .panel {
    overflow: auto;
    max-height: 30em;
    min-width: 19em;
}

.BackOfficeLayout .CollectionView .filters .new_filter_selector .panel a {
    border: none;
    background: none;
    display: block;
    cursor: pointer;
    text-decoration: none;
    text-align: left;
    padding: 0;
    margin: 0.8em 0;
}

.modal_selector_dialog {
    padding: 1em;
    height: auto;
    max-height: 92%;
    font-size: 85%;
}

.modal_selector_dialog .container {
    height: 80%;
}

.modal_selector_dialog .container .CheckList {
    -moz-column-width: 25em;
    -webkit-column-width: 25em;
}

.modal_selector_dialog .buttons {
    margin-top: 2em;
    text-align: right;
}

.modal_selector_dialog .buttons input {
    margin-left: 0.8em;
}

.BackOfficeLayout .modal_selector_control .select {
    vertical-align: middle;
    font-size: 90%;
}

.BackOfficeEditView .modal_selector_control {
    margin-bottom: 0.7em;
}

.BackOfficeEditView .modal_selector_control .container {
    padding-left: 1.5em;
}

.BackOfficeEditView .modal_selector_control .container > div {
    display: list-item;
    list-style-type: disc;
    font-size: 85%;
}

.BackOfficeLayout .modal_selector_control .container:empty {
    display: hidden;
}

.BackOfficeLayout .modal_selector_control .container .entry {
    margin-bottom: 0.5em;
}

/* Datepicker styles */

#ui-datepicker-div {
	background-color: rgb(255, 255, 255);
	border: 1px solid rgb(197, 203, 212);
}

#ui-datepicker-div .ui-datepicker-links a,
#ui-datepicker-div .ui-datepicker-header select {
	color: rgb(0, 0, 0);
	background-color: rgb(255, 255, 255);
}

.ui-datepicker .ui-datepicker-days-cell a {
	color: rgb(0, 0, 0);
	background-color: rgb(240, 240, 240);
}

.ui-datepicker .ui-datepicker-current-day a {
	background-color: rgb(225, 225, 225);
}

.ui-datepicker-next a,
.ui-datepicker-prev a {
    border: none;
}

.ui-datepicker-prev a,
.ui-datepicker-prev a:hover {
    background: url(/resources/images/date_arrow_left.gif) 50% 50% no-repeat;
}

.ui-datepicker-next a,
.ui-datepicker-next a:hover {
    background: url(/resources/images/date_arrow_right.gif) 50% 50% no-repeat;
}

.ui-datepicker-prev a:active,
.ui-datepicker-next a:active {
    background: none;
}

/* File form
-----------------------------------------------------------------------------*/
.FileFieldsView .upload_info {
    font-size: 90%;
    margin: 0;
    margin-top: 0.5em;
    margin-bottom: 0.4em;
    padding: 0;
    padding-bottom: 0.4em;
    padding-left: 2em;
    padding-top: 0.2em;
    background-repeat: no-repeat;
}

/* Edit stack
-----------------------------------------------------------------------------*/
.BackOfficeLayout .stack_node {
    border: 1px solid rgb(210,210,210);
    background-color: rgb(245,245,245);
    padding: 0.4em;
    padding-bottom: 0;
    padding-right: 0;
    margin-left: 0.8em;
}

.BackOfficeLayout .stack_node .stack_node {
    border-right: none;
    border-bottom: none;
}

.BackOfficeLayout .stack_node.root {
    margin: 0.8em;
    margin-top: 1.8em;
}

.BackOfficeLayout .stack_node > .label {
    font-weight: bold;
    margin-bottom: 0.8em;
    color: rgb(120,120,120);
    font-size: 85%;
}

.BackOfficeLayout .stack_node > .label > .relation {
}

.BackOfficeLayout .stack_node.top {
    border: 2px solid #ccc;
    background-color: white;
    padding-bottom: 2em;
}

.BackOfficeLayout .stack_node.top > .label {
    color: rgb(50,50,50);
    font-size: 100%;
}

.BackOfficeLayout .stack_node .body {
    margin: 0;
    padding: 0;
    padding: 0 0.4em;
}

/* Overwrite tiny styles to cutomize toolbar buttons */

/* External */
.defaultSkin .mceExternalClose {
    background:url(/resources/images/icons_tiny.gif) -820px 0 !important;
}

/* Layout */
.defaultSkin .mceStatusbar a.mceResize {
    background:url(/resources/images/icons_tiny.gif) -800px 0 !important;
}

body .defaultSkin .mceIcon {
   background: url(/resources/images/icons_tiny.gif) no-repeat 20px 20px;
}

/* Separator */
.defaultSkin .mceSeparator {
    background:url(/resources/images/icons_tiny.gif) -180px 0 !important;
}

/* ListBox */
.defaultSkin .mceListBox .mceOpen {
    background:url(/resources/images/icons_tiny.gif) -741px 0 !important;
}

/* SplitButton */
body .defaultSkin .mceSplitButton span.mceAction {
    background-image:url(/resources/images/icons_tiny.gif);
}
.defaultSkin .mceSplitButton a.mceOpen {
    background:url(/resources/images/icons_tiny.gif) -741px 0 !important;
}

/* Browse */
a.browse span {
    background:url(/resources/images/icons_tiny.gif) -860px 0 !important;
}
a.pickcolor span {
    background:url(/resources/images/icons_tiny.gif) -840px 0 !important;
}

/* Feed edit form
-----------------------------------------------------------------------------*/
.FeedFields .edit_form .ttl_field input.control,
.FeedFields .edit_form .limit_field input.control {
    width: 4em;
}

/* Member list
-----------------------------------------------------------------------------*/
.BackOfficeFieldsView .MemberList-autocomplete {
    width: 24em;
}

.BackOfficeFieldsView .MemberList-selection {
    padding: 0;
    margin: 0;
    list-style-type: none;
    font-size: 0.8em;
}

.BackOfficeFieldsView .MemberList-selection li {
    margin-left: 0.4em;
    margin-bottom: 0.4em;
    padding: 0;
}

.BackOfficeFieldsView .autocomplete_dropdown .content_type,
.BackOfficeFieldsView .MemberList-selection .content_type {
    color: rgb(75,75,75);
    font-weight: bold;
}

.BackOfficeFieldsView .MemberList-selection .remove_button {
    margin-left: 0.8em;
    vertical-align: pointer;
    cursor: pointer;
}

/* Calendar content view
-----------------------------------------------------------------------------*/

.BackOfficeLayout .CalendarContentView h1 {
    display: none;
    font-size: 110%;
}

.BackOfficeLayout .CalendarContentView .toolbar_box {
    height: 2em;
}

.BackOfficeLayout .CalendarContentView .toolbar {
    float: left;
}

.BackOfficeLayout .CalendarContentView .data_controls {
    float: right;
    width: auto;
    margin: 0.2em;
}

.BackOfficeLayout .CalendarContentView .date_controls * {
    font-size: 85%;
}

.BackOfficeLayout .CalendarContentView .layout_controls,
.BackOfficeLayout .CalendarContentView .navigation_links,
.BackOfficeLayout .CalendarContentView .navigation_controls {
    display: inline;
}

.BackOfficeLayout .CalendarContentView .navigation_links {
    margin-left: 3.6em;
}

.BackOfficeLayout .CalendarContentView .navigation_controls {
    margin-left: 1.8em;
}

.BackOfficeLayout .CalendarContentView .layout_controls a,
.BackOfficeLayout .CalendarContentView .navigation_links a {
    margin-right: 0.5em;
}

.BackOfficeLayout .CalendarContentView .navigation_links a.current_link {
    margin-right: 1em;
}

.BackOfficeLayout .CalendarContentView .year_control {
    width: 3.4em;
}

.BackOfficeLayout .CalendarContentView .day_control {
    width: 2.2em;
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar {
    clear: both;
    border-collapse: collapse;
    width: 100%;
    border: 1px solid rgb(200,205,212);
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar th {
    color: rgb(75,75,75);
    padding: 0.4em;
    font-size: 85%;
    text-align: left;
    background-position: bottom left;
    background-repeat: repeat-x;
    background-image: url(/resources/images/header.png);
    background-color: rgb(220,223,227);
    border: 1px solid rgb(200,205,212);
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td {
    border: 1px solid rgb(215,215,215);
    width: 14%;
    padding: 0.4em;
    vertical-align: top;
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td.inactive {
    background-color: rgb(235,235,235);
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td.today {
    outline: 1px solid rgb(220,180,140);
    background-color: rgb(255,245,230);
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td .cell {
    min-height: 4em;
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td .day {
    color: rgb(110,110,110);
    font-weight: bold;
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td.weekday6 .day {
    color: rgb(130,60,30);
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td .entries {
    font-size: 75%;
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td .calendar_entry {
    margin-top: 0.8em;
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td .calendar_entry .time {
    font-weight: bold;
    color: rgb(50,50,50);
    font-size: 85%;
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td .calendar_entry .member {
    color: rgb(75,75,75);
    font-style: italic;
    font-size: 85%;
}

.BackOfficeLayout .CalendarContentView .collection_display .month_calendar td .calendar_entry a {
    text-decoration: none;
}

.BackOfficeLayout .CalendarContentView .collection_display .year_calendar .month_header a {
    color: inherit;
    font-weight: bold;
    font-size: 110%;
    text-decoration: none;
}

.BackOfficeLayout .CalendarContentView .collection_display .year_calendar {
    font-size: 85%;
}

.BackOfficeLayout .CalendarContentView .collection_display .year_calendar .month_calendar {
    width: auto;
    float: left;
    clear: none;
    margin-top: 0.8em;
    margin-right: 0.8em;
}

.BackOfficeLayout .CalendarContentView .collection_display .year_calendar .month_calendar th {
    font-weight: normal;
}

.BackOfficeLayout .CalendarContentView .collection_display .year_calendar .month_calendar td .cell {
    position: relative;
    overflow: visible;
    min-height: 0;
    height: 1em;
    width: 1.2em;
    text-align: center;
}

.BackOfficeLayout .CalendarContentView .collection_display .year_calendar .month_calendar td .has_entries .day {
    font-weight: bold;
    color: black;
    cursor: pointer;
}

.BackOfficeLayout .CalendarContentView .collection_display .year_calendar .month_calendar .day {
    font-weight: normal;
}

.BackOfficeLayout .CalendarContentView .collection_display .year_calendar .month_calendar .entries {
    text-align: left;
    display: none;
    position: absolute;
    top: 1.1em;
    border: 1px solid rgb(190,200,210);
    background-color: rgb(250,250,250);
    margin: 0;
    padding: 0.6em;
    z-index: 1;
    font-size: 100%;
    white-space: nowrap;
}

.BackOfficeLayout .CalendarContentView .collection_display .year_calendar .month_calendar .entries div {
    margin: 0.4em 0;
}

.BackOfficeLayout .CalendarContentView .collection_display .time_table {
    border-collapse: collapse;
}

.BackOfficeLayout .CalendarContentView .collection_display .time_table td {
    border: 1px solid rgb(215,215,215);
}

.BackOfficeLayout .CalendarContentView .collection_display .time_table th {
    text-align: right;
}

.BackOfficeLayout .CalendarContentView .ongoing_items_box {
    clear: both;
    padding-top: 1.4em;
}

.BackOfficeLayout .CalendarContentView .ongoing_items_box ul {
    display: inline;
    list-style-type: none;
    padding: 0;
    margin: 0;
}

.BackOfficeLayout .CalendarContentView .ongoing_items_box li {
    display: inline;
}

.BackOfficeLayout .CalendarContentView .ongoing_items_box li + li:before {
    content: ', ';
}

/* TagCloudSelector
-----------------------------------------------------------------------------*/
.TagCloudSelector {
    line-height: 2em;
}

.TagCloudSelector div {
    display: inline;
    margin-right: 0.4em;
}

.TagCloudSelector div label {
    display: inline;
    float: none !important;
    padding: 0.1em;
}

.TagCloudSelector div.selected label {
    color: white;
    background-color: rgb(40,80,150);
}

/* Publishable edit styles
-----------------------------------------------------------------------------*/
.Publishable .cache_expiration_field .field_instance input.control {
    width: 5em;
}

/* Trigger edit styles
-----------------------------------------------------------------------------*/
.Trigger .condition_field .control {
    width: 30em !important;
}

.Trigger .condition_field .CodeMirror-wrapping {
    width: 30em !important;
    height: 2.5em !important;
}

/* Syndication feed styles
-----------------------------------------------------------------------------*/
.Feed .item_title_expression_field .CodeMirror-wrapping,
.Feed .item_link_expression_field .CodeMirror-wrapping,
.Feed .item_publication_date_expression_field .CodeMirror-wrapping,
.Feed .item_description_expression_field .CodeMirror-wrapping {
    width: 30em !important;
    height: 2.5em !important;
}

/* Tweaks for custom trigger responses
-----------------------------------------------------------------------------*/
.CustomTriggerResponse .field_instance {
    width: 90%;
}

.CustomTriggerResponse .code_field .control {
    width: 100% !important;
    height: 35em !important;
}

/* Tweaks for email templates
-----------------------------------------------------------------------------*/
.EmailTemplate .sender_field .CodeMirror-wrapping,
.EmailTemplate .receivers_field .CodeMirror-wrapping,
.EmailTemplate .bcc_field .CodeMirror-wrapping {
    height: 5em;
}

.EmailTemplate .subject_field .control,
.EmailTemplate .body_field .control {
    width: 30em !important;
}

.EmailTemplate .body_field .control {
    height: 25em;
}

/* Static site extension
-----------------------------------------------------------------------------*/
.ExportStaticSiteView .body p {
    margin-bottom: 0.6em;
}

.ExportStaticSiteView .export_form {
    margin-top: 1em;
}

.ExportStaticSiteView .export_form .field_instance-CheckBox .field_label {
    font-size: 0.9em;
}

.ExportStaticSiteView .export_form .buttons {
    text-align: left;
    padding-left: 0;
}

.ExportStaticSiteView .Form div.field {
    margin-bottom: 0;
}

.ExportStaticSiteView .body ul {
    list-style-type: none;
    padding: 0;
    margin: 0;
}

.ExportStaticSiteView .body li {
    padding: 0;
    margin: 0;
    margin-bottom: 0.2em;
    margin-left: 0.2em;
}

.ExportStaticSiteView .exported_content_list li {
    margin-bottom: 0.4em;
}

.ExportStaticSiteView .body li a {
    text-decoration: none;
}

.ExportStaticSiteView .language_field input {
    vertical-align: middle;
}

.ExportStaticSiteView .export_log table {
    border-collapse: collapse;
    margin-left: 1em;
    margin-top: 0.5em;
}

.ExportStaticSiteView .export_log td {
    padding-top: 0.4em;
    padding-bottom: 0.4em;
    padding-right: 2em;
    vertical-align: middle;
    border-bottom: 1px solid rgb(225,225,225);
}

.ExportStaticSiteView .export_log .ContentLink {
    text-decoration: none;
}

.ExportStaticSiteView .export_log .language {
    color: rgb(100,100,100);
    font-size: 80%;
}

.ExportStaticSiteView .export_log .outcome_cell {
    padding-left: 1.4em;
    background-repeat: no-repeat;
    background-position: 0 0.4em;
}

.ExportStaticSiteView .export_log .exported .outcome_cell {
    color: rgb(20,80,20);
    background-image: url(/resources/images/staticsite-status-exported.png);
}

.ExportStaticSiteView .export_log .failed .outcome_cell {
    color: rgb(135,35,10);
    background-image: url(/resources/images/staticsite-status-failed.png);
}

.ExportStaticSiteView .export_log .error_cell {
    color: rgb(75,75,75);
    text-decoration: italic;
}

/* Vimeo video extension
-----------------------------------------------------------------------------*/
.VimeoSynchronizationView .buttons {
    text-align: left;
    padding-left: 0;
}

.VimeoSynchronizationView .back_form {
    margin-top: 2em;
}

.VimeoSynchronizationView .result_block {
    margin-top: 1.4em;
    clear: left;
}

.VimeoSynchronizationView .result_block .title {
    font-weight: bold;
}

.VimeoSynchronizationView .result_block .videos {
    margin: 0.4em;
}

.VimeoSynchronizationView .result_block .video {
    margin-top: 1em;
    clear: left;
    overflow: hidden;
}

.VimeoSynchronizationView .result_block .video_title {
    color: rgb(75,75,75);
    font-weight: bold;
}

.VimeoSynchronizationView .result_block .thumbnail {
    float: left;
    margin-right: 0.8em;
}

.VimeoSynchronizationView .result_block .ContentLink {
    font-weight: bold;
    text-decoration: none;
}

.VimeoSynchronizationView .result_block .description {
    font-size: 85%;
    padding: 0.2;
}

.BackOfficePreviewView iframe {
    width: 100%;
    height: 600px;
    margin-top: 0.5em;
}

.BackOfficePreviewView .preview_language_selector {
    padding-top: 0.5em;
    float: right;
}

.BackOfficePreviewView .language_dropdown_label {
    display: inline-block;
    vertical-align: baseline;
    font-size: 0.9em;
}

.BackOfficePreviewView .language_dropdown > .panel_wrapper > .panel {
    min-width: 10em;
    left: auto;
    right: 0;
}

.BackOfficePreviewView .language_dropdown .entry + .entry {
    margin-top: 0.2em;
}

.BackOfficePreviewView .language_dropdown .entry_link {
    white-space: nowrap;
    text-decoration: none;
    font-size: 0.9em;
}

/* Tweaks for password change process
-----------------------------------------------------------------------------*/
div.success_label {
    border: 1px solid rgb(200,220,200);
    background-color: rgb(220,240,220);
    text-align: left;
    float: left;
    padding: 0.4em;
    margin: 0.8em;
    clear: both;
    width: 90%
}

/* Bulk file uploader
-----------------------------------------------------------------------------*/
.BackOfficeUploadFilesView .imported_files_list {
    list-style-type: none;
    padding: 0;
    padding-left: 0.5em;
    margin: 0;
}

.BackOfficeUploadFilesView .imported_files_list li {
    margin-top: 1em;
}

.BackOfficeUploadFilesView .imported_files_list .ContentLink {
    text-decoration: none;
}

.BackOfficeUploadFilesView .upload_another {
    margin-top: 1.5em;
}

/* Item palette
-----------------------------------------------------------------------------*/
.ItemPalette,
.ItemPalette .group_entries,
.ItemPalette .nested_groups {
    list-style-type: none;
    padding: 0;
    margin: 0;
    display: block;
}

.ItemPalette .group_label {
    font-size: 0.9em;
    font-weight: bold;
    color: #545F75;
    border-bottom: 2px solid #ADB2BC;
    padding-bottom: 0.2em;
    margin-top: 1.2em;
    margin-bottom: 0.6em;
}

.ItemPalette .palette_group.with_label .palette_group .group_label {
    font-size: 0.8em;
    color: #555;
    border-bottom: 1px dotted #ccc;
}

.ItemPalette li {
    white-space: nowrap;
}

.ItemPalette li + li {
    margin-top: 0.3em;
}

.ItemPalette li a {
    text-decoration: none;
}

.ItemPalette li a * {
    vertical-align: middle;
}

.ItemPalette .palette_entry .button {
    display: inline-block;
}

.ItemPalette .palette_entry .type_icon {
    margin-right: 0.4em;
}

/* BackOfficeItemViewOverlay
-----------------------------------------------------------------------------*/
.BackOfficeItemView .block_map .explanation {
    font-size: 0.85em;
}

.BackOfficeItemView .block_map .block_list {
    list-style-type: none;
    padding: 0;
    padding-left: 0.5em;
    margin: 0;
    margin-top: 0.5em;
}

.BackOfficeItemView .block_map .block_list .ItemLabel {
    font-size: 0.75em;
}

/* BackOfficeItemHeading
-----------------------------------------------------------------------------*/
.BackOfficeItemHeading {
    margin-bottom: 1.5em;
}

.stack_node .BackOfficeItemHeading {
    margin-top: 1em;
}

.BackOfficeItemHeading .item_path {
    vertical-align: top;
}

.BackOfficeItemHeading .item_path ul {
    list-style-type: none;
    display: inline-block;
    vertical-align: top;
    padding: 0;
    margin: 0;
    margin-left: 0.4em;
}

.BackOfficeItemHeading .item_path li {
    display: inline-block;
    vertical-align: top;
    padding: 0;
}

.BackOfficeItemHeading .item_path li + li:before {
    position: relative;
    top: 0.1em;
    content: '>';
    margin: 0 0.4em;
    color: #666;
    font-weight: bold;
    font-size: 1.2em;
}

.BackOfficeItemHeading .item_path li a {
    display: inline-block;
    vertical-align: top;
}

/* ReferenceList
-----------------------------------------------------------------------------*/
.BackOfficeReferencesView .item_body {
    margin: 1em;
}

.BackOfficeReferencesView .summary {
    margin-top: 2em;
    margin-bottom: 1.5em;
}

.BackOfficeReferencesView .references_table {
    border-collapse: collapse;
}

.BackOfficeReferencesView .references_table .ContentLink {
    text-decoration: none;
    white-space: nowrap;
}

.BackOfficeReferencesView .references_table .referrer_cell {
    padding-right: 2em;
}

.BackOfficeReferencesView .references_table .relation_cell {
    color: #666;
    font-size: 80%;
    white-space: nowrap;
}

.BackOfficeReferencesView .references_table td,
.BackOfficeReferencesView .references_table th {
    text-align: left;
    padding: 0.4em 0;
    padding-right: 2em;
    font-size: 0.9em;
}

.BackOfficeReferencesView .references_table th {
    border-bottom: 1px solid #ccc;
    padding-bottom: 0.2em;
    color: #333;
}

/* Content drag & drop
-----------------------------------------------------------------------------*/
.BackOfficeLayout .drag {
    opacity: 0.7;
}

.BackOfficeLayout .dropReceiver {
    position: relative;
    background-color: #a6eeff;
    background-image: -webkit-linear-gradient(#e4eff2,#ccdade);
    background-image: -moz-linear-gradient(#e4eff2,#ccdade);
    background-image: linear-gradient(#e4eff2,#ccdade);
    outline: 1px dashed #a6c5cc;
}

.BackOfficeLayout .dropBeforeReceiver {
    position: relative;
    margin-top: -1px;
    border-top: 1px dashed #ccdade;
}

.BackOfficeLayout .dropAfterReceiver {
    position: relative;
    margin-bottom: -1px;
    border-bottom: 1px dashed #ccdade;
}

.BackOfficeLayout .dragInsertionMarker {
    position: absolute;
    background-repeat: no-repeat;
    background-image: url(/resources/images/insertion_marker.png);
    background-position: left center;
    padding-left: 0.8em;
    white-space: nowrap;
}

/* BackOfficeInstallationSyncView
-----------------------------------------------------------------------------*/
.BackOfficeInstallationSyncView .item_body {
    padding-top: 1em;
    padding-left: 0.5em;
}

.BackOfficeInstallationSyncView .item_body section + section {
    margin-top: 2em;
}

.BackOfficeInstallationSyncView .item_body section > h1 {
    font-size: 1em;
    color: #333;
    margin-top: 0;
    padding-bottom: 0.2em;
    border-bottom: 1px solid #ddd;
}

.BackOfficeInstallationSyncView .item_body .item_list {
    list-style-type: none;
    margin: 0;
    padding: 0;
}

.BackOfficeInstallationSyncView .item_body .item_list li + li {
    margin-top: 0.4em;
}

.BackOfficeInstallationSyncView .item_body .item_list li .item_check {
    margin: 0;
    margin-right: 0.3em;
}

.BackOfficeInstallationSyncView .item_body .item_list .item_description {
    padding-right: 2em;
}

.BackOfficeInstallationSyncView .item_body .item_list select {
    display: table-cell;
}

.BackOfficeInstallationSyncView .ObjectDiff {
    margin-left: 1.4em;
}

.Dialog.diff_dialog {
    top: auto;
    left: auto;
    right: auto;
    bottom: auto;
    width: auto;
    height: auto;
}

.Dialog.diff_dialog .dialog_header {
    padding: 0.6em 0;
}

.Dialog.diff_dialog .dialog_heading {
    font-size: 1.2em;
}

.Dialog.diff_dialog .dialog_header .icon {
    margin-right: 0.2em;
    position: relative;
    top: 0.1em;
}

.Dialog.diff_dialog .dialog_content {
    overflow: auto;
    max-height: 50em;
}

.Dialog.diff_dialog .differences {
    margin: 0;
}

.BackOfficeInstallationSyncView .ObjectDiff .differences,
.diff_dialog .ObjectDiff .differences {
    border-collapse: collapse;
}

.BackOfficeInstallationSyncView .ObjectDiff .differences th,
.BackOfficeInstallationSyncView .ObjectDiff .differences td,
.diff_dialog .ObjectDiff .differences th,
.diff_dialog .ObjectDiff .differences td {
    border: 1px solid #ccc;
    padding: 0.4em 0.8em !important;
}

.BackOfficeInstallationSyncView .modified_section .diff_dialog_button {
    font-size: 0.7em;
    margin-left: 1em;
    text-decoration: none;
}

.BackOfficeInstallationSyncView .selection_controls {
    float: none;
    margin: 0;
    margin-top: 2em;
    padding: 0;
}

.BackOfficeInstallationSyncView .sync_buttons {
    margin-top: 1em;
}

/* ObjectDiff
-----------------------------------------------------------------------------*/
.ObjectDiff .differences {
    margin: 1em 0;
    font-size: 85%;
}

.ObjectDiff .differences th {
    padding-bottom: 0.75em;
}

.ObjectDiff .diff_add {
    color: rgb(0,125,0);
    font-weight: bold;
}

.ObjectDiff .diff_sub {
    color: rgb(150,0,0);
    font-weight: bold;
}

.ObjectDiff .diff_change {
    color: rgb(25,25,175);
    font-weight: bold;
}

.ObjectDiff .language {
    color: rgb(75,75,75);
    font-style: italic;
    font-size: 85%;
}

.ObjectDiff .differences td,
.ObjectDiff .differences th {
    text-align: left;
    vertical-align: top;
}

.ObjectDiff .differences th + th,
.ObjectDiff .differences td + td {
    padding-left: 1em;
}

.ObjectDiff .diff_unit {
    display: inline-block;
}

.ObjectDiff .diff_unit + .diff_unit {
    margin-left: 0.5em;
}

.ObjectDiff .collection_diff .diff_unit {
    display: block;
}

.ObjectDiff .collection_diff .diff_unit + .diff_unit {
    margin-left: 0;
}

.BackOfficeDiffView .ObjectDiff .differences .check {
    width: 1em;
}

.BackOfficeDiffView .buttons {
    text-align: left;
    padding: 0;
    margin: 1em 0;
}

/* Annotations extension
-----------------------------------------------------------------------------*/
.BackOfficeLayout .Form .annotation_dropdown {
    position: relative;
    left: -1.9em;
    top: 0.3em;
}

.BackOfficeLayout .Form .field.annotationTarget input[type=text].control,
.BackOfficeLayout .Form .field.annotationTarget input[type=password].control,
.BackOfficeLayout .Form .field.annotationTarget input[type=email].control,
.BackOfficeLayout .Form .field.annotationTarget input[type=url].control,
.BackOfficeLayout .Form .field.annotationTarget input[type=tel].control {
    padding-right: 2em;
}

.BackOfficeLayout .Form .annotation_dropdown > .button .icon {
    -webkit-filter: grayscale(100%);
    filter: grayscale(100%);
    margin: 0.1em 0.2em;
}

.BackOfficeLayout .Form .field_instance.with_annotation .annotation_dropdown > .button .icon {
    -webkit-filter: none;
    filter: none;
}

.BackOfficeLayout .Form .annotation_dropdown .dropdown_arrow {
    display: none;
}

.BackOfficeLayout .Form .annotation_dropdown textarea {
    width: 100%;
    height: 16em;
}

.BackOfficeLayout .Form .annotation_dropdown > .panel_wrapper > .panel {
    left: -15em;
    right: -0.8em;
}

.BackOfficeLayout .Form .field_instance-RichTextEditor .annotation_dropdown {
    left: -2.5em;
    top: -1.5em;
}

.BackOfficeLayout .Form .field_instance-RichTextEditor .annotation_dropdown > .panel_wrapper > .panel {
    top: -0.1em;
    left: -25.2em;
    right: -1.4em;
}

