#-*- coding: utf-8 -*-
u"""

.. moduleauthor:: Jordi Fernández <jordi.fernandez@whads.com>
"""
from cocktail.translations import translations


# YouTubeVideo
#------------------------------------------------------------------------------
translations.define("YouTubeVideo",
    ca = u"Vídeo de YouTube",
    es = u"Video de YouTube",
    en = u"YouTube video"
)

translations.define("YouTubeVideo-plural",
    ca = u"Vídeos de YouTube",
    es = u"Videos de YouTube",
    en = u"YouTube videos"
)

translations.define("YouTubeVideo.content",
    ca = u"Contingut",
    es = u"Contenido",
    en = u"Content"
)

translations.define("YouTubeVideo.title",
    ca = u"Títol",
    es = u"Título",
    en = u"Title"
)

translations.define("YouTubeVideo.video_id",
    ca = u"Identificador del vídeo",
    es = u"Identificador del video",
    en = u"Video ID"
)

# YouTubeVideoRenderer
#------------------------------------------------------------------------------
translations.define("YouTubeVideoRenderer",
    ca = u"Pintador de fotogrames pels vídeos de YouTube",
    es = u"Pintador de fotogramas para los videos de YouTube",
    en = u"YouTube videos still renderer"
)

translations.define("YouTubeVideoRenderer-plural",
    ca = u"Pintadors de fotogrames pels vídeos de YouTube",
    es = u"Pintadores de fotogramas para los videos de YouTube",
    en = u"YouTube videos still renderers"
)

# VideoPlayerSettings
#------------------------------------------------------------------------------
translations.define("VideoPlayerSettings.youtube",
    ca = u"YouTube",
    es = u"YouTube",
    en = u"YouTube"
)

translations.define("VideoPlayerSettings.youtube_allow_fullscreen",
    ca = u"Permetre pantalla completa",
    es = u"Permitir pantalla completa",
    en = u"Allow fullscreen"
)

translations.define("VideoPlayerSettings.youtube_show_info",
    ca = u"Sobreimpressionar el títol del vídeo",
    es = u"Sobreimpresionar el título del video",
    en = u"Overlay the video title"
)

translations.define("VideoPlayerSettings.youtube_show_related_videos",
    ca = u"Mostrar vídeos relacionats",
    es = u"Mostrar videos relacionados",
    en = u"Show related videos"
)

