#-*- coding: utf-8 -*-
u"""

.. moduleauthor:: Jordi Fernández <jordi.fernandez@whads.com>
"""
from cocktail.translations import translations


# TV3ALaCartaVideo
#------------------------------------------------------------------------------
translations.define("TV3ALaCartaVideo",
    ca = u"Vídeo de TV3 a la carta",
    es = u"Video de TV3 a la carta",
    en = u"TV3 a la carta video"
)

translations.define("TV3ALaCartaVideo-plural",
    ca = u"Vídeos de TV3 a la carta",
    es = u"Videos de TV3 a la carta",
    en = u"TV3 a la carta videos"
)

translations.define("TV3ALaCartaVideo.content",
    ca = u"Contingut",
    es = u"Contenido",
    en = u"Content"
)

translations.define("TV3ALaCartaVideo.title",
    ca = u"Títol",
    es = u"Título",
    en = u"Title"
)

translations.define("TV3ALaCartaVideo.video_id",
    ca = u"Identificador del vídeo",
    es = u"Identificador del video",
    en = u"Video ID"
)

